#include "config.h"
#include "genlib.h"
#include "dosfs.h"
#include "cli.h"

#include <cyg/hal/drv_api.h>
#include <cyg/io/io.h>
#include <cyg/io/devtab.h>
#include <cyg/io/disk.h>


#define ctl_base (int*)CF_CTL_BASE
#define ctl_irq  (int )CF_CTL_IRQ
#define ide_base (int*)CF_IDE_BASE
#define ide_irq  (int )CF_IDE_IRQ

// ----------------------------------------------------------------------------
// wait_for_idle
//
// Wait until any outstanding IDE operations have completed. This will return
// 1 for success, or zero in the event of a timeout.

/* Partition types supported by the FAT driver */
typedef struct
{
  unsigned char   Id;
  unsigned char * Name;

} PARTITION_TYPE, * PPARTITION_TYPE;

PARTITION_TYPE PartitionTypes[] =
{
  { 0x01, "FAT12"                       },
  { 0x04, "FAT16 up to 32 MB"           },
  { 0x06, "FAT16 over 32 MB"            },
  { 0x0B, "FAT32"                       },
  { 0x0C, "FAT32 using LBA BIOS"        },
  { 0x0E, "FAT16 using LBA BIOS"        },
  { 0x1B, "Hidden FAT32"                },
  { 0x1C, "Hidden FAT32 using LBA BIOS" },
  { 0x1E, "Hidden VFAT"                 },
  { 0, 0 }
};


static inline int wait_for_idle(cyg_uint32* ctlr)
{
  cyg_uint8 status;
  cyg_ucount32 tries;

  for (tries=0; tries<1000000; tries++)
  {
    ALT_AVALON_CF_READ_UINT8(ctlr, IDE_REG_STATUS, status);
    if (!(status & IDE_STAT_BSY))
    {
      return 1;
    }
  }
  return 0;
}

// ----------------------------------------------------------------------------
// wait_for_drq
//
// Wait until the device reports that data is ready. This will return 1 for
// success, or zero in the event of a timeout.

static inline int wait_for_drq(cyg_uint32* ctlr)
{
  cyg_uint8 status;
  cyg_ucount32 tries;

  int i = 0;

  for( i = 0; i < 2000; i++){}
 // CYGACC_CALL_IF_DELAY_US(10);
  for (tries=0; tries<1000000; tries++)
  {
    ALT_AVALON_CF_READ_UINT8(ctlr, IDE_REG_STATUS, status);
    if (!(status & IDE_STAT_BSY))
    {
      if (status & IDE_STAT_DRQ)
  return 1;
      else
      {
  return 0;
      }
    }
  }
  return 0;
}



int CFPresent(void)
{
  if( (IORD_ALTERA_AVALON_CF_CTL_STATUS(ctl_base) & ALTERA_AVALON_CF_CTL_STATUS_PRESENT_MSK))
  {
    return 1;
  }
  else
  {
    return 0;
  }
}


static void id_strcpy(char *dest, unsigned short *src, unsigned short size)
{
  int i;

  for (i = 0; i < size; i+=2)
  {
    *dest++ = (char)(*src >> 8);
    *dest++ = (char)(*src & 0x00FF);
    src++;
  }
  *dest = '\0';
}


static void cfReset(void* pCtlBase)
{
  IOWR_ALTERA_AVALON_CF_CTL_CONTROL(ctl_base,
            ALTERA_AVALON_CF_CTL_STATUS_POWER_MSK |
            ALTERA_AVALON_CF_CTL_STATUS_RESET_MSK);

  monDelay(5);

  IOWR_ALTERA_AVALON_CF_CTL_CONTROL(ctl_base,
            ALTERA_AVALON_CF_CTL_STATUS_POWER_MSK);

  monDelay(1000);

}

static int ide_ident(unsigned int * ctlr, int dev,unsigned short *buf)
{
  int i;

  wait_for_drq(ctlr);

  ALT_AVALON_CF_WRITE_UINT8(ctlr, IDE_REG_DEVICE, dev << 4);
  ALT_AVALON_CF_WRITE_UINT8(ctlr, IDE_REG_COMMAND, 0xEC);
  monDelay(5);

  if (!wait_for_drq(ctlr))
  {
    return 0;
  }

  for (i = 0;
       i < (512 / sizeof(cyg_uint16));
       i++, buf++)
  {
    ALT_AVALON_CF_READ_UINT16(ctlr, IDE_REG_DATA, *buf);
  }
  return 1;
}



static int cfInsert( void)
{

//  alt_avalon_cf_info_t info;

  unsigned int id_buf[512/sizeof(unsigned int)];
  cyg_disk_identify_t ident;
  ide_identify_data_t *ide_idData=(ide_identify_data_t*)id_buf;

  // Check to see if there's a device available

  if (!CFPresent())
  {
    return false;
  }

  // Having found a device, interogate it for its parameters

  printf("IDE %d identify drive\n", 0);

  if (!ide_ident(ide_base, 0, (unsigned short *)id_buf))
  {
    return false;
  }

  id_strcpy(ident.serial, ide_idData->serial,       20);
  id_strcpy(ident.firmware_rev, ide_idData->firmware_rev, 8);
  id_strcpy(ident.model_num, ide_idData->model_num,    40);

  ident.cylinders_num   = ide_idData->num_cylinders;
  ident.heads_num       = ide_idData->num_heads;
  ident.sectors_num     = ide_idData->num_sectors;
  ident.lba_sectors_num = ide_idData->lba_total_sectors[1] << 16 | ide_idData->lba_total_sectors[0];

  printf("\tSerial        : %s\n", ident.serial);
  printf("\tFirmware Rev. : %s\n", ident.firmware_rev);
  printf("\tModel         : %s\n", ident.model_num);
  printf("\tC/H/S         : %d/%d/%d\n", ident.cylinders_num, ident.heads_num, ident.sectors_num);
  printf("\tKind          : %x\n", (ide_idData->general_conf>>8)&0x1f);
  printf("\tMode          : %d\n", (ide_idData->pio_xferc_imting >> 8));

  return true;
}



cyg_bool cfInit( void * pCtlBase)
{
  int rval;

  printf("IDE(%d:%d) hw init\n", ide_base, 0);

  // turn the power on
  IOWR_ALTERA_AVALON_CF_CTL_CONTROL(ctl_base, ALTERA_AVALON_CF_CTL_STATUS_POWER_MSK);

  // Reset the interface
  cfReset(ctl_base);

  IORD_ALTERA_AVALON_CF_CTL_STATUS(ctl_base);

  // attempt to insert the device
  rval = cfInsert();

  // enable insert detect irq
  IORD_ALTERA_AVALON_CF_CTL_STATUS(ctl_base);


    IOWR_ALTERA_AVALON_CF_CTL_CONTROL(ctl_base,
              ALTERA_AVALON_CF_CTL_STATUS_POWER_MSK
              + ALTERA_AVALON_CF_CTL_STATUS_IRQ_EN_MSK);

  return rval;
}

char *cfHelp[] =
{
  "Compact Flash FAT File System",
  "-[df:i:mvx] operation [args]...",
#if INCLUDE_VERBOSEHELP
  "",
  "Options:",
  " -d    tfs device",
  " -f    flags (see below)",
  " -i    info",
  " -m    enable more throttle",
  " -v    enable verbosity",
  " -x    set exit flag if error",
  "",
  "Operations (alphabetically):",
  "cat", " info", " init",
  "",
  "Flags:",
#endif
  0,
};



void cfInfo( void)
{
   int i;
	uint8_t sector[SECTOR_SIZE]; //, sector2[SECTOR_SIZE];
	uint32_t pstart, psize;
	uint8_t pactive, ptype;
	VOLINFO vi;
	DIRINFO di;
	DIRENT de;
//	uint32_t cache;
//	FILEINFO fi;
//	uint8_t *p;

   char tmp[15];
   char buf[80];

   memset( buf, ' ', sizeof(buf));

	// Obtain pointer to first partition on first (only) unit
	pstart = DFS_GetPtnStart(0, sector, 0, &pactive, &ptype, &psize);
	if (pstart == 0xffffffff) {
		printf("Cannot find first partition\n");
		return;
	}

	printf("Partition 0 :\n");
	printf("Start Sector: 0x%x\n", pstart);
	printf("Active      :   %x\n", pactive);

   for( i = 0; PartitionTypes[i].Id != 0; i++)
   {
      if ( PartitionTypes[i].Id == ptype)
      {
      	printf("Type        :   %s\n", PartitionTypes[i].Name);
         break;
      }
   }

	printf("Size        :   %x\n", psize);

	if (DFS_GetVolInfo(0, sector, pstart, &vi))
	{
		printf("Error getting volume information\n");
		return;
	}

	printf("Volume label        : '%s'\n", vi.label);
	printf("Sector/s per Cluster: %d\n",   vi.secperclus);
	printf("Reserved Sector/s   : %d\n",   vi.reservedsecs);
	printf("Total Sectors       : %d\n",   vi.numsecs);

	printf("Sectors per FAT     : %d\n",vi.secperfat);
	printf("FAT at Sector       : %d\n",vi.fat1);
	printf("Root Dir at Sector  : %d\n",vi.rootdir);

	printf("Root Dir Entries    : %d\n",vi.rootentries);
	printf("Data Area at Sector : %d\n",vi.dataarea);

	printf("Clusters            : %d\n", vi.numclusters);
	printf("Bytes in Data Area  : %d\n", vi.numclusters * vi.secperclus * SECTOR_SIZE);
	printf("Filesystem          : ");

	if (vi.filesystem == FAT12)
		printf("FAT12\n");
	else if (vi.filesystem == FAT16)
		printf("FAT16\n");
	else if (vi.filesystem == FAT32)
		printf("FAT32\n");
	else
		printf("[unknown]\n");

	di.scratch = sector;
	if (DFS_OpenDir(&vi, "", &di)) {
		printf("Error opening root directory\n");
		return;
	}

	while (!DFS_GetNext(&vi, &di, &de))
	{
		if (de.name[0])
		{
         memset( buf, ' ', sizeof(buf));


		   // a valid file or directory name
         if (( de.attr & ATTR_DIRECTORY) > 0)
         {
            // truncate the extension
            de.name[8] = 0;
            sprintf( buf,"%02d/%02d/%4d  %02d:%02d   <DIR>            %-8s\0",CREATE_MON(de), CREATE_DAY(de), CREATE_YEAR(de), CREATE_HR(de), CREATE_MIN(de), de.name);
         }
         else
         {
            DFS_DirToCanonical( tmp, de.name);

            sprintf( buf,"%02d/%02d/%4d  %02d:%02d          %8d  %-11s\0",CREATE_MON(de), CREATE_DAY(de), CREATE_YEAR(de), CREATE_HR(de), CREATE_MIN(de), FILESIZE(de), tmp);
         }

			printf("%s\n", buf);


		}
	}
}

void cfCat( char * fileName, int more)
{
  uint8_t  sector[SECTOR_SIZE];
  uint32_t pstart,  psize, i;
  uint8_t  pactive, ptype;
  uint8_t *p;

  VOLINFO  vi;
  FILEINFO fi;

  // Obtain pointer to first partition on first (only) unit
  pstart = DFS_GetPtnStart(0, sector, 0, &pactive, &ptype, &psize);

  if (pstart == 0xffffffff)
  {
    printf("Cannot find first partition\n");
    return;
  }

  printf("Partition 0 start sector 0x%8x active %2x type %2x size %x\n", pstart, pactive, ptype, psize);

  if (DFS_GetVolInfo(0, sector, pstart, &vi))
  {
    printf("Error getting volume information\n");
    return;
  }

  if (DFS_OpenFile(&vi, fileName, DFS_READ, sector, &fi))
  {
    printf("error opening file: %s\n", fileName);
    return;
  }

  p = (void *) malloc(fi.filelen+512);

  memset(p, 0xaa, fi.filelen+512);

  DFS_ReadFile(&fi, sector, p, &i, fi.filelen);
  printf("read complete %d bytes (expected %d) pointer %d\n", i, fi.filelen, fi.pointer);
}

int
cf(int argc, char *argv[])
{

  int opt, verbose, more, retval, setexitflag, status;
  char   *info, *flags, *devprefix;
  char  *arg1, *arg2, *arg3, *arg4;

  retval      = CMD_SUCCESS;
  more        = 0;
  verbose     = 0;
  status      = 0;
  setexitflag = 0;

  flags       = (char *)0;
  devprefix   = (char *)0;

  if( CFPresent())
  {
    printf("CF Card Present\n");
  }
  else
  {
    printf("CF Card Not Present\n");
    retval = CMD_PARAM_ERROR;
    goto done;
  }

  while ((opt = getopt(argc, argv, "d:vmf:i:x")) != -1)
  {
    switch (opt)
    {
       case 'd':
        devprefix = optarg;
        break;
      case 'f':
        flags = optarg;
        break;
      case 'i':
        info = optarg;
        break;
      case 'm':
        more++;
        break;
      case 'v':
        verbose++;
        break;
      case 'x':
        setexitflag = 1;
        break;
      default:
        retval = CMD_PARAM_ERROR;
        goto done;
      }
  }

  arg1 = argv[optind];    // cmd
  arg2 = argv[optind+1];  // sub command
  arg3 = argv[optind+2];
  arg4 = argv[optind+3];

  if (argc == optind)
  {
    retval = CMD_PARAM_ERROR;
  }
  else if (strcmp(arg1, "info") == 0)
  {
      cfInfo();
  }
  else if (strcmp(arg1, "init") == 0)
  {
      cfInit( ctl_base);
  }
  else if ((strcmp(arg1, "cat") == 0) && ( argc >= (optind+2)))
  {
      cfCat( arg2, more << 3);
  }
  else if ((strcmp(arg1, "ls") == 0) && ( argc >= (optind+2))) {
      cfCat( arg2, more << 3);
  }
  else
  {
    retval = CMD_PARAM_ERROR;
  }
done:
  return(retval);

}




uint32_t DFS_ReadSector(uint8_t unit, uint8_t *buffer, uint32_t sector, uint32_t count)
//static int
//ide_read_sector(int ctlr, int dev, cyg_uint32 start,
//                cyg_uint8 *buf, cyg_uint32 len)
{
    int j;
    uint16_t   p;
    uint8_t  * b=buffer;

    ALT_AVALON_CF_WRITE_UINT8( ide_base, IDE_REG_COUNT, count);    // count =1
    ALT_AVALON_CF_WRITE_UINT8( ide_base, IDE_REG_LBALOW,   sector        & 0xff);
    ALT_AVALON_CF_WRITE_UINT8( ide_base, IDE_REG_LBAMID,  (sector >>  8) & 0xff);
    ALT_AVALON_CF_WRITE_UINT8( ide_base, IDE_REG_LBAHI,   (sector >> 16) & 0xff);
    ALT_AVALON_CF_WRITE_UINT8( ide_base, IDE_REG_DEVICE, ((sector >> 24) & 0xf) | (0 << 4) | 0x40);
    ALT_AVALON_CF_WRITE_UINT8( ide_base, IDE_REG_COMMAND, 0x20);

    if (!wait_for_drq( ide_base))
        return 1;
    //
    // It would be fine if all buffers were word aligned,
    // but who knows
    //
    for (j = 0; j < (512 / sizeof(cyg_uint16)); j++)
    {
        ALT_AVALON_CF_READ_UINT16( ide_base, IDE_REG_DATA, p);

        *b++=p&0xff;
        *b++=(p>>8)&0xff;
    }

    return 0;
}

uint32_t DFS_WriteSector(uint8_t unit, uint8_t *buffer, uint32_t sector, uint32_t count)
{
  int        j;
  uint16_t   p;
  uint8_t  * b=buffer;

  if (!wait_for_idle(ide_base))
  {
    return 1;
  }

  ALT_AVALON_CF_WRITE_UINT8(ide_base, IDE_REG_COUNT, count);    // count =1
  ALT_AVALON_CF_WRITE_UINT8(ide_base, IDE_REG_LBALOW,  sector & 0xff);
  ALT_AVALON_CF_WRITE_UINT8(ide_base, IDE_REG_LBAMID, (sector >>  8) & 0xff);
  ALT_AVALON_CF_WRITE_UINT8(ide_base, IDE_REG_LBAHI,  (sector >> 16) & 0xff);
  ALT_AVALON_CF_WRITE_UINT8(ide_base, IDE_REG_DEVICE,((sector >> 24) & 0xf) | (0 << 4) | 0x40);
  ALT_AVALON_CF_WRITE_UINT8(ide_base, IDE_REG_COMMAND, 0x30);

  if (!wait_for_drq( ide_base))
  {
    return 1;
  }

  // It would be fine if all buffers were word aligned, but who knows.

  for (j = 0; j < ( SECTOR_SIZE / sizeof( uint16_t)); j++)
  {
    p  =  *b++;
    p |= (*b++ << 8);

    ALT_AVALON_CF_WRITE_UINT16( ide_base, IDE_REG_DATA, p);
  }

  return 0;
}

