#define __ADSPLPBLACKFIN__
#include "config.h"
#include "genlib.h"
#include "i2c.h"
#include "cdefBF537.h"
#include "cpuio.h"
#include "cli.h"

#define I2CADD_CAMERA		0xB8

void
dmaInit(int height, int width)
{
	*pDMA0_START_ADDR = (void *)getAppRamStart();
	*pDMA0_X_COUNT = width;
	*pDMA0_CURR_X_COUNT = 0;
	*pDMA0_X_MODIFY = 1;
	asm("ssync");
	*pDMA0_Y_COUNT = height;
	*pDMA0_CURR_Y_COUNT = 0;
	*pDMA0_Y_MODIFY = 1;
	asm("ssync");
	*pDMA0_CONFIG = 0x00b2;
	asm("ssync");
}

void
ppiInit(int height, int width)
{
	*pPPI_STATUS = 0;
	*pPPI_DELAY = 1;
	*pPPI_COUNT = width - 1;
	*pPPI_FRAME = height;
	*pPPI_CONTROL = 0x002c;
	asm("ssync");
}

void
setCameraReg(int regno, unsigned short val)
{
	unsigned char data[4];

	data[0] = regno;					/* Register # */
	data[1] = (val & 0xff00) >> 8;		/* High byte  */
	data[2] = (val & 0x00ff);			/* Low  byte  */
	i2cWrite(0,I2CADD_CAMERA,data,3);
}

char *PicHelp[] = {
	"Take a picture, put data at APPRAMBASE.",
	"",
	0,
};

int
PicCmd(int argc, char *argv[])
{
	volatile int tot;
	volatile int timeout;
	int height = 240;
	int width = 376;

	CAMERA_RESET_1();
	CAMERA_SELECT();

#ifdef TRY_SNAPSHOT_MODE
	EXPOSURE_0();
	setCameraReg(7,0x0390);
#else
	setCameraReg(7,0x0388);
	EXPOSURE_1();
#endif

	dmaInit(height, width);
	ppiInit(height, width);

	*pDMA0_CONFIG |= DMAEN;
	asm("ssync");
	*pPPI_CONTROL |= PORT_EN;
	asm("ssync");

#ifdef TRY_SNAPSHOT_MODE
	EXPOSURE_1();
	monDelay(2);
	EXPOSURE_0();
#endif

	while(*pDMA0_CURR_X_COUNT == 0);
	
	tot = 0;
	timeout = 1000000;

	while(tot < 5) {
		if (gotachar())
			break;
		if ((*pDMA0_CURR_X_COUNT == 0) && (*pDMA0_CURR_Y_COUNT == 1))
			tot++;
		else
			tot = 0;
	}
	*pPPI_CONTROL &= ~PORT_EN;
	asm("ssync");
	*pDMA0_CONFIG &= ~DMAEN;
	asm("ssync");

	/* At this point, the image should be in APPRAMBASE. */
	return(CMD_SUCCESS);
}
