/* DRAM stuff...
 */
#define TRAS	5
#define TRP		2

/* Uart stuff...
 */
#define DEFAULT_BAUD_RATE 57600
#define THR		0x00
#define RBR		0x00
#define DLL		0x00
#define DLH		0x04
#define IER		0x04
#define LCR		0x0c
#define MCR		0x10
#define LSR		0x14
#define SCR		0x1c
#define GCTL	0x24

#define UART0_BASE		0xffc00400
#define UART1_BASE		0xffc02000
#define RS232_PORT		UART0_BASE
#define RS485_PORT		UART1_BASE
#define CONSOLE(reg)	(RS232_PORT+reg)
#define RS485(reg)		(RS485_PORT+reg)

/************************************************************************
 *
 * Port F GPIO control:
 * There are differences between RevA and RevB hardware...
 */
#if HARDWARE_IS_REVA

#define DS3_REDBIT		0x0400
#define ISO_INBIT		0x0800
#define ISO_OUT1BIT		0x1000
#define ISO_OUT2BIT		0x2000
#define DS3_GREENBIT	0x4000
#define LED_BITMASK		(DS2_GREENBIT | DS2_REDBIT | DS3_GREENBIT | DS3_REDBIT)

#define DS3_GREEN()		*pPORTFIO_SET   = DS3_GREENBIT
#define DS3_NOTGREEN()	*pPORTFIO_CLEAR = DS3_GREENBIT
#define DS3_RED()		*pPORTFIO_SET   = DS3_REDBIT
#define DS3_NOTRED()	*pPORTFIO_CLEAR = DS3_REDBIT
#define DS3_OFF()		*pPORTFIO_CLEAR = (DS3_REDBIT | DS3_GREENBIT)
#define DS3_ON()		*pPORTFIO_SET	= (DS3_REDBIT | DS3_GREENBIT)
#define INCNT_SET()		*pPORTFIO_CLEAR	= ISO_OUT1BIT
#define INCNT_CLR()		*pPORTFIO_SET	= ISO_OUT1BIT
#define OUTCNT_SET()	*pPORTFIO_CLEAR	= ISO_OUT2BIT
#define OUTCNT_CLR()	*pPORTFIO_SET	= ISO_OUT2BIT

#elif HARDWARE_IS_REVB

#define ISO_OUT2BIT		0x0080
#define DS3_YELLOWBIT	0x4000
#define LED_BITMASK		(DS2_GREENBIT | DS2_REDBIT | DS3_YELLOWBIT)

#define DS3_YELLOW()	*pPORTFIO_SET   = DS3_YELLOWBIT
#define DS3_NOTYELLOW()	*pPORTFIO_CLEAR = DS3_YELLOWBIT
#define DS3_OFF()		DS3_NOTYELLOW()
#define DS3_ON()		DS3_YELLOW()
#define OUTCNT_SET()	*pPORTFIO_CLEAR	= ISO_OUT2BIT
#define OUTCNT_CLR()	*pPORTFIO_SET	= ISO_OUT2BIT
#else
#error: HW Rev not specified
#endif

/* Some port F GPIO bits are the same for either rev...  */

#define DS2_REDBIT		0x0040
#define DS2_GREENBIT	0x0010
#define TX485_EN		0x0020

#define DS2_GREEN()		*pPORTFIO_SET   = DS2_GREENBIT
#define DS2_NOTGREEN()	*pPORTFIO_CLEAR = DS2_GREENBIT
#define DS2_RED()		*pPORTFIO_SET   = DS2_REDBIT
#define DS2_NOTRED()	*pPORTFIO_CLEAR = DS2_REDBIT
#define DS2_OFF()		*pPORTFIO_CLEAR = (DS2_REDBIT | DS2_GREENBIT)
#define DS2_ON()		*pPORTFIO_SET	= (DS2_REDBIT | DS2_GREENBIT)
#define STATLED_OFF()	DS3_OFF()
#define STATLED_ON()	DS3_ON()


/* Port G GPIO control:
 * Some changes between RevA and RevB hardware...
 */
#if HARDWARE_IS_REVA

#define CAMERA_RESET_BIT	0x0400
#define DECODER_RESET_BIT	0x1000
#define EXPOSURE_BIT		0x4000
#define AB_SELECT_BIT		0x8000

#define CAMERA_RESET_1()	*pPORTGIO_SET	= CAMERA_RESET_BIT
#define CAMERA_RESET_0()	*pPORTGIO_CLEAR	= CAMERA_RESET_BIT
#define DECODER_RESET_1()	*pPORTGIO_SET	= DECODER_RESET_BIT
#define DECODER_RESET_0()	*pPORTGIO_CLEAR	= DECODER_RESET_BIT
#define EXPOSURE_1()		*pPORTGIO_SET	= EXPOSURE_BIT
#define EXPOSURE_0()		*pPORTGIO_CLEAR	= EXPOSURE_BIT
#define DECODER_SELECT()	*pPORTGIO_SET	= AB_SELECT_BIT
#define CAMERA_SELECT()		*pPORTGIO_CLEAR	= AB_SELECT_BIT

#elif HARDWARE_IS_REVB

#define ISO_INBIT			0x0100
#define CAMERA_RESET_BIT	0x0400
#define ISO_OUT1BIT			0x0800
#define EXPOSURE_BIT		0x8000		

#define DECODER_RESET_1()	*pPORTGIO_SET	= 0		/* Dummy function */
#define DECODER_RESET_0()	*pPORTGIO_CLEAR	= 0		/* Dummy function */
#define DECODER_SELECT()	*pPORTGIO_SET	= 0		/* Dummy function */
#define CAMERA_SELECT()		*pPORTGIO_CLEAR	= 0		/* Dummy function */
#define CAMERA_RESET_1()	*pPORTGIO_SET	= CAMERA_RESET_BIT
#define CAMERA_RESET_0()	*pPORTGIO_CLEAR	= CAMERA_RESET_BIT
#define EXPOSURE_1()		*pPORTGIO_SET	= EXPOSURE_BIT
#define EXPOSURE_0()		*pPORTGIO_CLEAR	= EXPOSURE_BIT
#define INCNT_SET()			*pPORTGIO_CLEAR	= ISO_OUT1BIT
#define INCNT_CLR()			*pPORTGIO_SET	= ISO_OUT1BIT

#endif

extern int IFlush(char *addr);
extern int Flush(char *addr);
extern int FlushInv(char *addr);
extern int PreFetch(char *addr);
extern int rs485_gotachar(void);
extern int rs485_putchar(int);
extern int rs485_getchar(void);


/* If for some reason, DMA-based character reception on the UARTs is
 * not desireable, then comment out this definition...
 */
#define DMA_UART_RCV

/* Addresses and strings used with I-Squared-C.
 */
#if HARDWARE_IS_REVA
#define RM_ADDR				"0xA0"
#define RC_ADDR				"0xD0"
#define RAMTRON_MEMORY		0xA0
#define RAMTRON_COMPANION	0xD0
#elif HARDWARE_IS_REVB
#define RM_ADDR				"0xA2"
#define RC_ADDR				"0xD2"
#define RAMTRON_MEMORY		0xA2
#define MAXIM_RTC			0xD0
#define RAMTRON_COMPANION	0xD2
#endif

/* SPI Setup:
 * The baudrate is set to the slowest speed of all devices on
 * the SPI interface.  In our case, the only device is the ATMEL
 * flash which can run at 70Mhz.
 */
#define SPI_BAUDRATE	70000000
