//****************************************************************************
//
// File Name: EthLoop.c
//
// LoopBack Test:
//    -Sets up the CS8900 registers for loop back.
//    -Bids for and transmits a frame.
//    -Polls the receive register for the receive frame
//    -Verifies that the data is correct.
//
// Copyright (c) 2001 Cirrus Logic, Inc.
//
//*****************************************************************************
//
// The following is the basic flow of the loopback test program
//
// This procedure assumes you are using 10B-T.  Use a "loopback" cable,
// included in the EDB7312 evaluation kit in a small bag with the title
// "Ethernet Loopback Connector for EthLoop.c Code".  
// A regular 10B-T cable connected to a hub will not work.
//
// Configure RxCTL for Promiscious mode, RxOK 
// (1) Write 0x0104 to IOBase+0xA (PacketPage Pointer)
// (2) Write 0x0180h to IOBase+0xC (PacketPage Data Port)
//
// Configure TestCTL (FDX, DisableLT)
// (3) Write 0x0118 to IOBase+0xA (PacketPage Pointer)
// (4) Write 0x4080 to IOBase+0xC (PacketPage Data Port)
//
// Set 10BaseT, SerRxOn, SerTxOn in LineCTL
// (5) Write 0x0112 to IOBase+0xA (PacketPage Pointer)
// (6) Write 0x00C0 to IOBase+0xC (PacketPage Data Port)
//
// Write the TX command
// (7) Write 00C0h to IOBase+0x4 (PacketPage Pointer)
//
// Write the frame length  (XX = number of bytes to TX)
// (8) Write 00XXh to IOBase+0x6 (PacketPage Pointer)
//
// Read BusST to verify it is set as 0x0118 (Rdy4TxNow is set)
// (9) Write 0x0138 to IOBase+0xA (PacketPage Pointer)
// (10) Read IOBase+0xC  Should read 0x0118
//
// Copy the TX frame to the on-chip buffer 
// (11) Write XX/2 words to IOBase+0x0 (TX Data Port)
//
// At this point the frame should go out on the wire.
//
// To read the TX'd frame:
//
// Read RxEvent for RxOK (0x0104)
// (12) Write 0x0124 to IOBase+0xA (PacketPage Pointer)
// (13) Read IOBase+0xC  Should read 0x0104 or 0x0504h
//
// Read IOBase+0  This will be the RxStatus (RxEvent) word again.
// Read IOBase+0 again.  This will be the RxLength (number of bytes received).
// Read IOBase+0 (RxLength/2) times to read complete frame.
//
//************************************************************************
#include "config.h"
#include "cpuio.h"
#include "genlib.h"
#include "stddefs.h"
#include "ethloop.h"

int eth_tst( void );
void eth_rst( void);
int eth_tst( void );

char *eth_tstHelp[] = {
	" This command perfroms a loopback test ",
	" on the CS8900A on the CSB226.",
    " Usage:",
    " eth_tst",
    " Options...",
    " None",
	0
};

//**************************************************************************
//  eth_tst()
//**************************************************************************
int eth_tst( void )
{
   unsigned short int i, j, receive_frame_size, temp;

   printf("\nBegin LoopBack test..............\n");

	// Initialize the part
//	eth_rst();

	// Configure RxCTL for Promiscious mode, RxOK 
	// (1) Write 0x0104 to IOBase+0xA (PacketPage Pointer)
	// (2) Write 0x0180h to IOBase+0xC (PacketPage Data Port)
	//
	outport( (IO_BASE + PP_POINTER ), 0x0104 );
	outport( (IO_BASE + PP_DATA ), 0x0180 );

	//
	// Configure TestCTL (FDX, DisableLT, ENDEC loop ) */
	// (3) Write 0x0118 to IOBase+0xA (PacketPage Pointer)
	// (4) Write 0x4080 to IOBase+0xC (PacketPage Data Port)*/
	//
	outport( (IO_BASE + PP_POINTER ), 0x0118 );
	outport( (IO_BASE + PP_DATA ), 0x4000 );

	//
	// Set 10BaseT, SerRxOn, SerTxOn in LineCTL 
	// (5) Write 0x0112 to IOBase+0xA (PacketPage Pointer)
	// (6) Write 0x00C0 to IOBase+0xC (PacketPage Data Port)
	//
	outport( (IO_BASE + PP_POINTER ), 0x0112 );
	outport( (IO_BASE + PP_DATA ), 0x00c0 );


	for (i = 0; i < NO_FRAMES_TO_SEND ; i++)
	{
		// Write the TX command 
		// (7) Write 00C0h to IOBase+0x4 
		outport( (IO_BASE + TX_CMD ), 0x00c0 );

		// Write the frame length  (XX = number of bytes to TX)
		//(8) Write 00XXh to IOBase+0x6 
		outport( ( IO_BASE + TX_LENGTH ), SIZE_OF_FRAME * 2 ); 

		//(9) Write 0x0138 to IOBase+0xA (PacketPage Pointer)
		outport( (IO_BASE + PP_POINTER), 0x0138 );

		// delay for a while
		for ( j = 0; j < 10000; j++);

		// (10) Read IOBase+0xC,  Should read 0x0118 to indicate Ready
		// for a transfer now.
		if ( (temp=inport(IO_BASE + PP_DATA)) !=  0x0118)
		{
			printf("Bid for transmit failed.\n");
			printf("Register PP_DATA = 0x%04x.\n", temp);
			return(FAILURE);
		}

		// Copy the TX frame to the on-chip buffer 
		// (11) Write XX/2 words to IOBase+0x0 (TX Data Port) 
		for (j = 0; j < SIZE_OF_FRAME; j++)
		{
			outport( IO_BASE , WORD_DATA );
		}

		// Delay for a while
		for ( j = 0; j < 30000; j++);
		for ( j = 0; j < 30000; j++);
		for ( j = 0; j < 30000; j++);
		for ( j = 0; j < 30000; j++);
		for ( j = 0; j < 30000; j++);
		for ( j = 0; j < 30000; j++);
		for ( j = 0; j < 30000; j++);
		for ( j = 0; j < 30000; j++); 

		// Read RxEvent for RxOK (0x0104) 
		// (12) Write 0x0124 to IOBase+0xA (PacketPage Pointer)
		// (13) Read IOBase+0xC  Should read 0x0104h or 0x0504h
		outport ( (IO_BASE + PP_POINTER), 0x0124);
		if ((temp = inport (IO_BASE + PP_DATA)) != 0x0104)
		{
			printf("Frame not received.\n");
			printf("Register 0x0124 PP_DATA = 0x%04x.\n", temp);
			eth_rst();
			return( FAILURE );
		}

		// Read IOBase+0  This should be the RxStatus (RxEvent) word again.
		if ( (temp = inport ( IO_BASE )) != 0x0104)
		{
			printf("Frame not received -- reading data port.\n");
			printf("Register 0x0124 PP_DATA = 0x%04x.\n", temp);
			eth_rst();
			return( FAILURE );
		}

		// Read IOBase+0 again.  This should be the RxLength (number of bytes received).
		receive_frame_size = inport( IO_BASE );
		if (SIZE_OF_FRAME < 30)  // size in words, i.e. pad characters added
			if (receive_frame_size != 60)  // size in bytes because of pad characters
			{
				printf("Frame received is not the right size < 60.\n");
			    printf("Receive_frame_size = 0x%04x.\n", receive_frame_size);
			    eth_rst();
		    	return(FAILURE);
			}
		if (SIZE_OF_FRAME >= 30)
			if (receive_frame_size != (SIZE_OF_FRAME * 2))
			{
	   			printf("Frame received is not the right size >= 60.\n");
	   			printf("Receive_frame_size = 0x%04x ; Should be 0x%04x.\n", 
	            receive_frame_size, (SIZE_OF_FRAME * 2));
				eth_rst();
				return(FAILURE);
			}

		// Read IOBase+0 (RxLength/2) times to read complete frame.
		for (j = 0; j < SIZE_OF_FRAME ; j++ )
		{
			if ( (temp = inport( IO_BASE )) != WORD_DATA)
			{
		   		printf("Frame data does not match what was sent.\n");
		    	printf("Received Data  = 0x%04x.\n", temp);
				eth_rst();
				return(FAILURE);
		   	}
		}
		if (SIZE_OF_FRAME < 30) // need to issue a skip to flush pad chars
		{
			outport( IO_BASE + PP_POINTER , 0x0102);
			temp = inport ( IO_BASE + PP_DATA );
			outport( IO_BASE + PP_DATA , ( temp | SKIP ) );
		}
	} // for NO_FRAMES_TO_SEND
	eth_rst();
	printf("Loopback Test Completed Successfully!\n");

	return(SUCCESS);
}

//*************************************************************************
//
// eth_rst()
//
//*************************************************************************
void eth_rst()
{
   unsigned short int temp,j;

   // Reset the CS8900A device
   outport( ( IO_BASE + PP_POINTER ), 0x0114 );
   outport( ( IO_BASE + PP_DATA ), 0x0040 );

   // delay for a while
   for (j=0; j<30000; j++);

   // Wait for reset complete
   for (;;) {
      outport ( (IO_BASE + PP_POINTER), 0x0136);
      if(((temp=inport(IO_BASE + PP_DATA)) & 0x0080) != 0) break;
	}
}


