    .file "ram_reset.s"

/*
 * General notice:
 * This code is part of a boot-monitor package developed as a generic base
 * platform for embedded system designs.  As such, it is likely to be
 * distributed to various projects beyond the control of the original
 * author.  Please notify the author of any enhancements made or bugs found
 * so that all may benefit from the changes.  In addition, notification back
 * to the author will allow the new user to pick up changes that may have
 * been made by other users after this version of the code was distributed.
 *
 * Author:  Ed Sutter
 * email:   esutter@lucent.com
 * phone:   908-582-2351
 * 
 *
 * Modified for the CSB281 - MPC8245 Single Board
 *
 * ram_reset.s:
  */

#include "config.h"
#include "warmstart.h"
#include "arch_ppc.h"
#include "cpu_pci.h"	// get the config register defines

    .globl  coldstart
    .globl  warmstart
    .globl  ipaddr
    .globl  SPInit
    .extern start

    .text

#include "moncomptr.S"
#include "etheraddr.S"

    .balign     0x100
coldstart:
    li  r3, INITIALIZE
	b	warmstart

    .org     0x3000
warmstart:
    /* Disable I&D Cache before accessing any registers
     */
    mfspr   r5,DC_CST
    lis     r5,0x0400
    mtspr   DC_CST,r5
    isync
    mfspr   r5,IC_CST
    lis     r5,0x0400
    mtspr   IC_CST,r5
    isync

    /* Initialize MSR & SRR1
     */
    lis     r5,(MSR_ME|MSR_RI)@h
    ori     r5,r5,(MSR_ME|MSR_RI)@l
    mtmsr   r5
    isync
    mtspr   srr1,r5
    isync

    /* Initialize ICTRL, ICR & DEC:
     */
    lis     r5,(ISCT_SER7)@h
    ori		r5,r5,(ISCT_SER7)@l
    mtspr   ICTRL,r5
    lis     r5,(0)@h
    ori		r5,r5,(0)@l
    mtspr   ICR,r5
    lis     r5,(0x7FFFFFFF)@h
    ori     r5,r5,(0x7FFFFFFF)@l
    mtspr   dec,r5

	li		r0,r0
	mtmsr	r0				# Disable FPU/MMU/exceptions
	isync


SPInit:
    /* initialize the stack pointer, and be assured that it is mod16 */
    lis     sp, (MonStack+MONSTACKSIZE-4)@h
    ori     sp, sp, (MonStack+MONSTACKSIZE-4)@l
    addis   r5, r0, 0xffff
    ori     r5, r5, 0xfff8
    and     r1, r1, r5

	ba		start
	nop

