//==========================================================================
//
// lh79520_mem.h
//
// Author(s):    Michael Kelly, Cogent Computer Systems, Inc.
// Contributors: 
// Date:         02/16/2003
// Description:  This file contains register base addresses and offsets
//				 and access macros for the LH795200 Static and SDRAM
//				 Memory Controllers
//

//---------------------------------------
// Static Memory Controller
#define SMC_BCR0			0x000	// nCS0 Base Configuration Register
#define SMC_BCR1			0x004	// nCS1 Base Configuration Register
#define SMC_BCR2			0x008	// nCS2 Base Configuration Register
#define SMC_BCR3			0x00c	// nCS3 Base Configuration Register
#define SMC_BCR4			0x010	// nCS4 Base Configuration Register
#define SMC_BCR5			0x014	// nCS5 Base Configuration Register
#define SMC_BCR6			0x018	// nCS6 Base Configuration Register

// Bit defines for all Static MEmoryBank Configuration Registers
#define SMC_IDCY(_x_)		(_x_ & 0x0f)			// inter-cycle delay
#define SMC_WST1(_x_)		((_x_ & 0x1f) << 5)		// Wait States, SRAM or ROM
#define SMC_RBLE			0x00000400				// Byte Enables low during reads, nWE enabled
#define SMC_WST2(_x_)		((_x_ & 0x1f) << 11)	// Wait States, Burst ROM subsequent
#define SMC_BERR			0x01000000				// Bus Error Flag
#define SMC_WPERR			0x02000000				// Write Protect Error Flag
#define SMC_WP				0x04000000				// Write Protect Enable
#define SMC_BM				0x08000000				// Burst Mode Enable
#define SMC_MW8				0x00000000				// Bank Memory Width = 8
#define SMC_MW16			0x10000000				// Bank Memory Width = 16
#define SMC_MW32			0x20000000				// Bank Memory Width = 32

// bit defines for SDRAM registers
// SDRC_CFG0 - SDRAM Configuration Register 0
#define SDRC_CFG0_F0		0x00000002		// Bank0 is not 256Mbyte		
#define SDRC_CFG0_T0		0x00000004		// Bank0 SDRAMS are 16 or 32-bit width ) 0 = 8 bits)
#define SDRC_CFG0_B0		0x00000008		// Bank0 has 4 internal banks (0 = 2 banks)
#define SDRC_CFG0_F1		0x00000020		// Bank0 is not 256Mbyte		
#define SDRC_CFG0_T1		0x00000040		// Bank0 SDRAMS are 16 or 32-bit width ) 0 = 8 bits)
#define SDRC_CFG0_B1		0x00000080		// Bank0 has 4 internal banks (0 = 2 banks)
#define SDRC_CFG0_E			0x00020000		// 1 = SDCLK stops during idle, 0 = always active
#define SDRC_CFG0_C			0x00040000		// 0 = SDCKE goes low during idle, 1 = always high
#define SDRC_CFG0_X			0x00080000		// 0 = external bus = 32 bits, 1 = 16
#define SDRC_CFG0_CL1		0x00100000		// CAS to Data Latency = 1 clock
#define SDRC_CFG0_CL2		0x00200000		// CAS to Data Latency = 2 clocks
#define SDRC_CFG0_CL3		0x00300000		// CAS to Data Latency = 3 clocks
#define SDRC_CFG0_RC2		0x00800000		// RAS to CAS Delay = 2 clocks
#define SDRC_CFG0_RC3		0x00C00000		// RAS to CAS Delay = 3 clocks
#define SDRC_CFG0_AP		0x01000000		// 1 = Autoprecharge issued after every SDRAM command

// SDRC_CFG1 - SDRAM Configuration Register 1
#define SDRC_CFG1_NORM		0x00000000		// Place SDRAM interface in normal operation
#define SDRC_CFG1_PALL		0x00000000		// Issue Precharge All command to SDRAM
#define SDRC_CFG1_MODE		0x00000000		// Issue Set Mode command to SDRAM
#define SDRC_CFG1_NOP		0x00000000		// Issue continuous NOP's to SDRAM
#define SDRC_CFG1_R			0x00000000		// Enable Read Buffer
#define SDRC_CFG1_W			0x00000000		// Enable Write Buffer
#define SDRC_CFG1_B			0x00000000		// 1 = SDRAM state machine is busy
