/*
 * Monitor configuration file for CSB637
 *
 * Adapted by Mike Kelly, Cogent Computer Systems, Inc. email: mike@cogcomp.com
 *
 *
 * General notice:
 * This code is part of a boot-monitor package developed as a generic base
 * platform for embedded system designs.  As such, it is likely to be
 * distributed to various projects beyond the control of the original
 * author.  Please notify the author of any enhancements made or bugs found
 * so that all may benefit from the changes.  In addition, notification back
 * to the author will allow the new user to pick up changes that may have
 * been made by other users after this version of the code was distributed.
 *
 * Author:  Ed Sutter
 * email:   esutter@lucent.com
 * phone:   908-582-2351
 */

/* DEFAULT_ETHERADD & DEFAULT_IPADD:
 * Refer to notes in ethernet.c function EthernetStartup() for details
 * regarding the use of these definitions.
 * DEFAULT_IPADD could be set to "DHCP" or "BOOTP" as well.
 */
#define     DEFAULT_ETHERADD "00:23:31:37:"  	// Cogent Block
#define     DEFAULT_IPADD    "192.168.254.210"		

#define CPU_LE

//#define PRE_TFSAUTOBOOT_HOOK	sed_init
#define PRE_COMMANDLOOP_HOOK	sed_init

#define APPRAMBASE_OVERRIDE 0x20100000

/* Defining DONT_CENTER_MONHEADER eliminates the automatic centering
 * of the monitor's startup banner...
 */
#define DONT_CENTER_MONHEADER

/* LOOPS_PER_SECOND:
 * Approximately the size of a loop that will cause a 1-second delay.
 * This can be guestimated or modified with the sleep -c command at the
 * monitor command line.
 */
#define LOOPS_PER_SECOND    52000

/* Flash bank configuration:
 */
#define FLASHBANKS				1
#define SINGLE_FLASH_DEVICE 	1
#define FLASH_COPY_TO_RAM 		1
#define FLASH_BANK0_BASE_ADDR  	0x10000000
#define FLASH_PROTECT_RANGE  	"0-3"
#define FLASH_BANK0_WIDTH       2
#define FLASH_LARGEST_SECTOR    0x20000
#define LOCK_FLASH_PROTECT_RANGE

/* TFS definitions:
 *  TFSSTART:       Base address in FLASH at which TFS starts.
 *  TFSEND:         End address of TFS in FLASH.
 *  TFSSPARE:       Location of sector that is used as the spare sector
 *                  by TFS for defragmentation.
 *  TFSSPARESIZE:   Size of the spare sector used by TFS for defragmentation.
 *  TFSSECTORCOUNT: Number of eraseable sectors that TFS covers, not including
 *                  the TFSSPARE sector.
 */
#define TFSSPARESIZE			FLASH_LARGEST_SECTOR
#define TFS_DEVTOT				1
#define TFSSTART				(FLASH_BANK0_BASE_ADDR+0x80000)
#define TFSEND					(FLASH_BANK0_BASE_ADDR+0x007dffff)
#define TFSSPARE				(TFSEND+1)
#define TFSSECTORCOUNT			((TFSSPARE-TFSSTART)/0x20000)
#define TFS_EBIN_ELFMSBIN		1
#define TFS_VERBOSE_STARTUP		1
#define TFS_AUTOBOOT_ABORTABLE
#define TFS_ALTDEVTBL_BASE		&alt_tfsdevtbl_base

#define CPU_NAME        "AT91RM9200 ARM920T"
#ifdef USE_DRAM_128
#define PLATFORM_NAME   "Cogent CSB637 (128M)"
#else
#define PLATFORM_NAME   "Cogent CSB637"
#endif

/* Specify the size of the memory block (in monitor space) that is to be
 * allocated to malloc in the monitor.  Note that this size can be dynamically
 * increased using the heap extension option in the heap command.
 */
#define ALLOCSIZE		(64*1024)
#define MONSTACKSIZE	(8*1024)

/* Specify inclusion of subsystems within the monitor here.
 * Refer to comments in common/monitor/inc_check.h for details on
 * each of these macros.
 */
#define INCLUDE_VERBOSEHELP		1
#define INCLUDE_MALLOC			1
#define INCLUDE_SHELLVARS		1
#define INCLUDE_HWTMR			0
#define INCLUDE_PORTCMD			0
#define INCLUDE_MEMTRACE		1
#define INCLUDE_MEMCMDS         1
#define INCLUDE_EDIT            1
#define INCLUDE_DISASSEMBLER    1
#define INCLUDE_UNZIP           1
#define INCLUDE_ETHERNET        1
#define INCLUDE_ICMP	        1
#define INCLUDE_TFTP            1
#define INCLUDE_DHCPBOOT        1
#define INCLUDE_TFS             1
#define INCLUDE_TFSCLI          1
#define INCLUDE_TFSAPI          1
#define INCLUDE_TFSSCRIPT       1
#define INCLUDE_TFSSYMTBL       1
#define INCLUDE_XMODEM          1
#define INCLUDE_LINEEDIT        1
#define INCLUDE_EE              1
#define INCLUDE_FLASH           1
#define INCLUDE_STRACE          1
#define INCLUDE_CAST            1
#define INCLUDE_STRUCT          1
#define INCLUDE_REDIRECT        1
#define INCLUDE_QUICKMEMCPY     1
#define INCLUDE_PROFILER        0
#define INCLUDE_BBC             0
#define INCLUDE_SYSLOG          1
#define INCLUDE_STOREMAC        1
#define INCLUDE_SED				1
#define INCLUDE_GDB				1
#define INCLUDE_USRLVL			1
#define INCLUDE_JFFS2			1
#define INCLUDE_JFFS2ZLIB		1
#define INCLUDE_FATFS			1
#define INCLUDE_CF				1
#define INCLUDE_LCD				1

/* Inclusion of this next file will make sure that all of the above
 * inclusions are legal; and warn/adjust where necessary.
 */
#include "inc_check.h"
