//==========================================================================
//
// mx31.h
//
// Author(s):    Luis Torrico, Cogent Computer Systems, Inc.
// Contributors: 
// Date:         05/02/2008
// Description:  This file contains register base addresses and offsets
//				 and access macros for the MCIMX31 on-chip peripherals
//				 This was copied from the mc9328mx2l.h and peripherals not
//				 used by UMON have not been tested (and may not be defined).
//			     Use these defines with caution!!
//

#include "bits.h"
 /*
  * Default Memory Layout Definitions
  */
 
 #define L2CC_BASE_ADDR          0x30000000
 
 /*
  * AIPS 1
  */
 #define AIPS1_BASE_ADDR         0x43F00000
 #define AIPS1_CTRL_BASE_ADDR    AIPS1_BASE_ADDR
 #define MAX_BASE_ADDR           0x43F04000
 #define EVTMON_BASE_ADDR        0x43F08000
 #define CLKCTL_BASE_ADDR        0x43F0C000
 #define ETB_SLOT4_BASE_ADDR     0x43F10000
 #define ETB_SLOT5_BASE_ADDR     0x43F14000
 #define ECT_CTIO_BASE_ADDR      0x43F18000
 #define I2C_BASE_ADDR           0x43F80000
 #define I2C3_BASE_ADDR          0x43F84000
 #define OTG_BASE_ADDR           0x43F88000
 #define ATA_BASE_ADDR           0x43F8C000
 #define UART1_BASE_ADDR         0x43F90000
 #define UART2_BASE_ADDR         0x43F94000
 #define I2C2_BASE_ADDR          0x43F98000
 #define OWIRE_BASE_ADDR         0x43F9C000
 #define SSI1_BASE_ADDR          0x43FA0000
 #define CSPI1_BASE_ADDR         0x43FA4000
 #define KPP_BASE_ADDR           0x43FA8000
 #define IOMUXC_BASE_ADDR        0x43FAC000
 #define UART4_BASE_ADDR         0x43FB0000
 #define UART5_BASE_ADDR         0x43FB4000
 #define ECT_IP1_BASE_ADDR       0x43FB8000
 #define ECT_IP2_BASE_ADDR       0x43FBC000
 
 /*
  * SPBA
  */
 #define SPBA_BASE_ADDR          0x50000000
 #define MMC_SDHC1_BASE_ADDR     0x50004000
 #define MMC_SDHC2_BASE_ADDR     0x50008000
 #define UART3_BASE_ADDR         0x5000C000
 #define CSPI2_BASE_ADDR         0x50010000
 #define SSI2_BASE_ADDR          0x50014000
 #define SIM_BASE_ADDR           0x50018000
 #define IIM_BASE_ADDR           0x5001C000
 #define ATA_DMA_BASE_ADDR       0x50020000
 #define SPBA_CTRL_BASE_ADDR     0x5003C000
 
 /*
  * AIPS 2
  */
 #define AIPS2_BASE_ADDR         0x53F00000
 #define AIPS2_CTRL_BASE_ADDR    AIPS2_BASE_ADDR
 #define CCM_BASE_ADDR           0x53F80000
 #define FIRI_BASE_ADDR          0x53F8C000
 #define GPT1_BASE_ADDR          0x53F90000
 #define EPIT1_BASE_ADDR         0x53F94000
 #define EPIT2_BASE_ADDR         0x53F98000
 #define GPIO3_BASE_ADDR         0x53FA4000
 #define SCC_BASE                0x53FAC000
 #define SCM_BASE                0x53FAE000
 #define SMN_BASE                0x53FAF000
 #define RNGA_BASE_ADDR          0x53FB0000
 #define IPU_CTRL_BASE_ADDR      0x53FC0000
 #define AUDMUX_BASE             0x53FC4000
 #define MPEG4_ENC_BASE          0x53FC8000
 #define GPIO1_BASE_ADDR         0x53FCC000
 #define GPIO2_BASE_ADDR         0x53FD0000
 #define SDMA_BASE_ADDR          0x53FD4000
 #define RTC_BASE_ADDR           0x53FD8000
 #define WDOG_BASE_ADDR          0x53FDC000
 #define PWM_BASE_ADDR           0x53FE0000
 #define RTIC_BASE_ADDR          0x53FEC000

// ------------------------------------------
// CCM - Clock Control Module
// Register Defines for MCIMX31
#define CCM_BASE_ADD		0x53F80000
#define CCM_REG(_x_)		*(vulong *)(CCM_BASE_ADD + _x_)
#define CCM_CCMR 			0x00 	// Clock Source Control Register
#define CCM_PDR0 			0x04 	// Post Divider Register 0
#define CCM_PDR1 			0x08 	// Post Divider Register 1
#define CCM_RCSR 			0x0C 	// Reset Control and Source Register
#define CCM_MPCTL 			0x10 	// MCU PLL Control Register
#define CCM_UPCTL 			0x14 	// USB PLL Control Register
#define CCM_SPCTL 			0x18 	// Serial PLL Control Register
#define CCM_COSR 			0x1C 	// Clock Out Source Register
#define CCM_CGR0 			0x20 	// Clock Gating Register 0
#define CCM_CGR1 			0x24 	// Clock Gating Register 1
#define CCM_CGR2 			0x28 	// Clock Gating Register 2
#define CCM_WIMR			0x2C 	// Wakeup Interrupt Mask Register
#define CCM_LDC				0x30 	// Latch Divergence Counter Register
#define CCM_DCVR0			0x34 	// DPTC Comparator Value Register 0
#define CCM_DCVR1			0x38 	// DPTC Comparator Value Register 1
#define CCM_DCVR2			0x3C 	// DPTC Comparator Value Register 2
#define CCM_DCVR3			0x40 	// DPTC Comparator Value Register 3
#define CCM_LTR0			0x44 	// Load Tracking Register 0
#define CCM_LTR1			0x48 	// Load Tracking Register 1
#define CCM_LTR2			0x4C 	// Load Tracking Register 2
#define CCM_LTR3			0x50 	// Load Tracking Register 3
#define CCM_LTBR0			0x54 	// Load Tracking Buffer Register 0
#define CCM_LTBR1			0x58 	// Load Tracking Buffer Register 1
#define CCM_PMCR0			0x5C 	// Power Management Control Register 0
#define CCM_PMCR1			0x60 	// Power Management Control Register 1
#define CCM_PDR2 			0x18 	// Post Divider Register 2

//---------------------------------------
// UARTS
// Register Defines for MCIMX31
// additional UART defines are in mx31_uart.h
#define UART1_BASE_ADD		0x43F90000
#define UART2_BASE_ADD		0x43F94000
#define UART3_BASE_ADD		0x5000C000
#define UART4_BASE_ADD		0x43FB0000
#define UART5_BASE_ADD		0x43FB4000
#define UART1_REG(_x_)		*(vulong *)(UART1_BASE_ADD + _x_)
#define UART2_REG(_x_)		*(vulong *)(UART2_BASE_ADD + _x_)
#define UART3_REG(_x_)		*(vulong *)(UART3_BASE_ADD + _x_)
#define UART4_REG(_x_)		*(vulong *)(UART4_BASE_ADD + _x_)
#define UART5_REG(_x_)		*(vulong *)(UART5_BASE_ADD + _x_)

// ------------------------------------------
// WEIM - Wireless External Interface Module
// Individual bit and register defines are in mc9328mx21_mem.h
#define WEIM_BASE_ADD		0xB8002000
#define WEIM_REG(_x_)		*(vulong *)(WEIM_BASE_ADD + _x_)

// ------------------------------------------
// GPIO - General Purpose I/O
#define GPIO1_BASE_ADD      0x53FCC000
#define GPIO2_BASE_ADD      0x53FD0000
#define GPIO3_BASE_ADD      0x53FA4000
#define GPIO1_REG(_x_)		*(vulong *)(GPIO1_BASE_ADD + _x_)
#define GPIO2_REG(_x_)		*(vulong *)(GPIO2_BASE_ADD + _x_)
#define GPIO3_REG(_x_)		*(vulong *)(GPIO3_BASE_ADD + _x_)
#define GPIO_DR 			0x00 	// Data Register
#define GPIO_DIR 			0x04 	// Direction Register
#define GPIO_PSTAT 			0x08 	// Pad Status Register (read only)
#define GPIO_ICR1	 		0x0C 	// Input Configuration Register 1
#define GPIO_ICR2	 		0x10 	// Input Configuration Register 2
#define GPIO_IMASK	 		0x14 	// Interrupt Mask Register
#define GPIO_ISTAT	 		0x18 	// Interrupt Status Register

//---------------------------------------
// IPU - Image Processing Unit
// additional IPU defines are in mx31_lcd.h
#define IPU_BASE_ADD		0x53FC0000
#define IPU_REG(_x_)		*(vulong *)(IPU_BASE_ADD + _x_)
#define IPU_MAP(_x_)		*(vulong *)(IPU_BASE_ADD + 0x800 + _x_)



