//==========================================================================
//
// mx31_uart.h
//
// Author(s):    Luis Torrico, Cogent Computer Systems, Inc.
// Contributors: 
// Date:         05/02/2008
// Description:  This file contains offsets and bit defines
//				 for the MCIMX31 on-chip UARTS
//

#include "bits.h"

// Register offsets
#define UART_RXD				0x00		// Receiver Register
#define UART_TXD				0x40		// Transmitter Register
#define UART_CR1				0x80		// Control Register 1 				
#define UART_CR2				0x84		// Control Register 2 				
#define UART_CR3				0x88		// Control Register 3 				
#define UART_CR4				0x8C		// Control Register 4 				
#define UART_FCR				0x90		// FIFO Control Register 			
#define UART_SR1 				0x94		// Status Register 1 				
#define UART_SR2 				0x98		// Status Register 2 				
#define UART_ESC 				0x9C		// Escape Character Register 		
#define UART_TIM 				0xA0		// Escape Timer Register 			
#define UART_BIR 				0xA4		// BRM Incremental Register			
#define UART_BMR 				0xA8		// BRM Modulator Register 			
#define UART_BRC 				0xAC		// Baud Rate Count Register 			
#define UART_ONEMS 				0xB0		// One Millisecond Register 
#define UART_TS 				0xD4		// Test Register 1 					

// Bit defines - Refer to MCIMX31 Users Manual for more detailed information
//
// UART_RXD - Receiver Register
#define UART_RXD_CHRDY			BIT15		// 1 = Character Ready
#define UART_RXD_RXOK			BIT14		// 1 = Recive character has no error
#define UART_RXD_OVR			BIT13		// 1 = Rx fifo overrun
#define UART_RXD_FRAME			BIT12		// 1 = Framing error
#define UART_RXD_BRK			BIT11		// 1 = current character is a break
#define UART_RXD_PAR			BIT10		// 1 = current character has a Parity Error
#define UART_RXD_DATA_MASK		0xff		// received data byte

// UART_TXD - Transmitter Register
#define UART_TXD_DATA(_x_)		((_x_ & 0xff) << 0)	// Transmit Data

// UART_CR1 - Control Register 1 				
#define UART_CR1_ADEN			BIT15		// 1 = Enable the automatic baud rate detection interrupt
#define UART_CR1_ADBR			BIT14		// 1 = Enable automatic detection of baud rate
#define UART_CR1_TRDYEN			BIT13		// 1 = Enable the transmitter ready interrupt
#define UART_CR1_IDEN			BIT12		// 1 = Enable the IDLE bit interrupt
#define UART_CR1_ICD4			(0 << 10)	// 0 = Idle interrupt after 4 frames
#define UART_CR1_ICD8			(1 << 10)	// 1 = Idle interrupt after 8 frames
#define UART_CR1_ICD16			(2 << 10)	// 2 = Idle interrupt after 16 frames
#define UART_CR1_ICD32			(3 << 10)	// 3 = Idle interrupt after 32 frames
#define UART_CR1_RRDYEN			BIT9		// 1 = Enable the RRDY interrupt
#define UART_CR1_RDMAEN			BIT8		// 1 = Enable UART_RX_DMAREQ DMA request
#define UART_CR1_IREN			BIT7		// 1 = Enable the IR interface
#define UART_CR1_TXMPTYEN		BIT6		// 1 = Enable the transmitter FIFO empty interrupt
#define UART_CR1_RTSDEN			BIT5		// 1 = Enable RTSD interrupt
#define UART_CR1_SNDBRK			BIT4		// 1 = Send a BREAK character (continuous 0s)
#define UART_CR1_TDMAEN			BIT3		// 1 = Enable transmit DMA request
#define UART_CR1_ATDMAEN		BIT2		// 1 = Enable the DMA AGTIM interrupt
#define UART_CR1_DOZE			BIT1		// 1 = The UART is disabled when in DOZE state
#define UART_CR1_UARTEN			BIT0		// 1 = Enable the UART

// UART_CR2 - Control Register 2 				
#define UART_CR2_ESCI			BIT15		// 1 = Enable the escape sequence interrupt
#define UART_CR2_IRTS			BIT14		// 1 = Transmit regardless of the UARTx_RTS pin state
#define UART_CR2_CTSC			BIT13		// 1 = The UARTx_CTS pin is controlled by the receiver
#define UART_CR2_CTS			BIT12		// Drives UARTx_CTS pin (inverted) when CTSC bit is low
#define UART_CR2_ESCEN			BIT11		// 1 = Enable escape sequence detection
#define UART_CR2_RTEC_HI		0x00 << 9	// 0 = RTS interrupts on rising edge
#define UART_CR2_RTEC_LO		0x01 << 9	// 1 = RTS interrupts on falling edge
#define UART_CR2_RTEC_ANY		0x02 << 9	// 2 = RTS interrupts on either edge
#define UART_CR2_PREN			BIT8		// 1 = Enable parity generator and checker
#define UART_CR2_PROE			BIT7		// 1 = Generate Odd parity
#define UART_CR2_STPB			BIT6		// 0 = 1 stop bit, 1 = 2 stop bits
#define UART_CR2_WS				BIT5		// 0 = 7-bit data length, 1 = 8-bit
#define UART_CR2_RTSEN			BIT4		// 1 = Enable request to send interrupt
#define UART_CR2_ATEN			BIT3		// 1 = Aging timer interrupt enable
#define UART_CR2_TXEN			BIT2		// 1 = Enable the transmitter
#define UART_CR2_RXEN			BIT1		// 1 = Enable the receiver
#define UART_CR2_SRST			BIT0		// 0 = Reset the state machines, FIFOs and all status registers

// UART_UCR3 - Control Register 3 				
#define UART_CR3_DTEC_HI		(0 << 14)	// 0 = DTR Interrupt generated on rising edge
#define UART_CR3_DTEC_LO		(1 << 14)	// 1 = DTR Interrupt generated on falling edge
#define UART_CR3_DTEC_ANY		(2 << 14)	// 2 = DTR Interrupt generated on either edge
#define UART_CR3_DTREN			BIT13		// 1 = Enable the data terminal ready interrupt
#define UART_CR3_PARERREN		BIT12		// 1 = Enable the parity error interrupt
#define UART_CR3_FRAERREN		BIT11		// 1 = Enable the frame error interrupt
#define UART_CR3_DSR			BIT10		// Directly drives the DSR Pin
#define UART_CR3_DCD			BIT9		// Directly drives the DCD Pin
#define UART_CR3_RI				BIT8		// Directly drives the RI Pin
#define UART_CR3_ADNIMP			BIT7		// 1 = Keep old autobaud detection mechanism
#define UART_CR3_RXDSEN			BIT6		// 1 = Enable the Receive Data Status (RXDS) interrupt
#define UART_CR3_AIRINTEN		BIT5		// 1 = Enable the AIRINT interrupt
#define UART_CR3_AWAKEN			BIT4		// 1 = Enable the AWAKE interrupt
#define UART_CR3_DTRDEN			BIT3		// 1 = Enable the DTRD interrupt
#define UART_CR3_RXDMUXSEL		BIT2		// 1 = RXD pin goes to UART, 0 = IrDA
#define UART_CR3_INVT			BIT1		// 1 = Invert Infrared Transmision Pulses
#define UART_CR3_ACIEN			BIT0		// 1 = ACST interrupt enabled, 0 = disabled

// UART_CR4 - Control Register 4 				
#define UART_CR4_CTSTL(_x_)	((_x_ & 0x3f) << 10) // CTS deassertion threshold (# of bytes in RxFIFO - 32 max.)
#define UART_CR4_INVR			BIT9		// 0 = Active low IR Receieve detection, 1 =  Active High
#define UART_CR4_ENIRI			BIT8		// 1 = Serial infrared Interrupt enabled
#define UART_CR4_WKEN			BIT7		// 1 = Enable the WAKE interrupt
#define UART_CR4_IDDMAEN		BIT6		// 1 = Enable the DMA IDLE interrupt
#define UART_CR4_LPBYP			BIT5		// 0 = Low power features enabled, 1 = disabled
#define UART_CR4_TCEN			BIT3		// 1 = Enable Transmit Data Complete (TXDC) interrupt
#define UART_CR4_BKEN			BIT2		// 1 = Enable the Break Condition (BRKN) interrupt
#define UART_CR4_OREN			BIT1		// 1 = Enable Overrun (ORE) interrupt
#define UART_CR4_DREN			BIT0		// 1 = Enable Receive Data Ready (RDR) interrupt

// UART_FCR - FIFO Control Register 			
#define UART_FCR_TXTL(_x_)		((_x_ & 0x3f) << 10) // Transmit Fifo threshold (32 max.)
#define UART_FCR_RFDIV6			(0 << 7)	// 0 = Divide input clock by 6
#define UART_FCR_RFDIV5			(1 << 7)	// 1 = Divide input clock by 5
#define UART_FCR_RFDIV4			(2 << 7)	// 2 = Divide input clock by 4
#define UART_FCR_RFDIV3			(3 << 7)	// 3 = Divide input clock by 3
#define UART_FCR_RFDIV2			(4 << 7)	// 4 = Divide input clock by 2
#define UART_FCR_RFDIV1			(5 << 7)	// 5 = Divide input clock by 1
#define UART_FCR_RFDIV7			(6 << 7)	// 6 = Divide input clock by 7
#define UART_FCR_DCEDTE			BIT6		// 0 = DCE mode selected, 1 = DTE mode selected
#define UART_FCR_RXTL(_x_)		((_x_ & 0x3f) << 0) // Receive Fifo threshold (32 max.)

// UART_SR1 - Status Register 1 				
#define UART_SR1_PARITYERR		BIT15		// 1 = Parity error detected (write 1 to clear)
#define UART_SR1_RTSS			BIT14		// RTS Status (inverted)
#define UART_SR1_TRDY			BIT13		// 1 = The transmitter requires data (interrupt posted)
#define UART_SR1_RTSD			BIT12		// 1 = UARTx_RTS pin changed state since last clear (write 1 to clear)
#define UART_SR1_ESCF			BIT11		// 1 = Escape sequence detected (write 1 to clear)
#define UART_SR1_FRAMERR		BIT10		// 1 = Frame error detected (write 1 to clear)
#define UART_SR1_RRDY			BIT9		// 1 = RX Character(s) ready (interrupt posted)
#define UART_SR1_AGTIM			BIT8		// 1 = AGTIM is active, 0 = not active
#define UART_SR1_DTRD			BIT7		// DTR Delta
#define UART_SR1_RXDS			BIT6		// 1 = Receiver is IDLE
#define UART_SR1_AIRINT			BIT5		// 1 = A pulse was detected on the RXD pin (infrared mode only)
#define UART_SR1_AWAKE			BIT4		// 1 = A falling edge was detected on the RXD pin

// UART_SR2 - Status Register 2 				
#define UART_SR2_ADET			BIT15		// 1 = ASCII 'A' or 'a' was received (write 1 to clear)
#define UART_SR2_TXFE			BIT14		// 1 = The transmit buffer (TxFIFO) is empty
#define UART_SR2_DTRF			BIT13		// 1 = Programmed edge detected on UART2_DTR (write 1 to clear, UART2 only)
#define UART_SR2_IDLE			BIT12		// 1 = Idle condition detected (write 1 to clear)
#define UART_SR2_ACST			BIT11		// 1 = Measurement of bit length finished, 0 = not finished, (in autobaud)
#define UART_SR2_RIDELT			BIT10		// 1 = Ring indicator input has changed state, 0 = not changed state
#define UART_SR2_RIIN			BIT9		// 1 = No ring detected, 0 = detected
#define UART_SR2_IRINT			BIT8		// 1 = valid edge detected, infrared mode only (write 1 to clear)
#define UART_SR2_WAKE			BIT7		// 1 = start bit detected (write 1 to clear)
#define UART_SR2_DCDDELT		BIT6		// 1 = Data Carrier Detect input has changed state, 0 = Not changed state
#define UART_SR2_DCDIN			BIT5		// 1 = No carrier signal detected, 0 = detected
#define UART_SR2_RTSF			BIT4		// 1 = Programmed edge detected on RTS (write 1 to clear)
#define UART_SR2_TXDC			BIT3		// 1 = Transmit is complete
#define UART_SR2_BRCD			BIT2		// 1 = A BREAK condition was detected (write 1 to clear)
#define UART_SR2_ORE			BIT1		// 1 = Overrun error (write 1 to clear)
#define UART_SR2_RDR			BIT0		// 1 = Receive data ready

// UART_ESC - Escape Character Register 		
#define UART_ESC_MASK			0xff

// UART_TIM - Escape Timer Register 			
#define UART_TIM_MASK			0xfff

// UART_BIR  - BRM Incremental Register			
#define UART_BIR_MASK			0xffff

// UART_BMR - BRM Modulator Register 			
#define UART_BMR_MASK			0xffff

// UART_BRC - Baud Rate Count Register 			
#define UART_BRC_MASK			0xffff

// UART_ONEMS - One Millisecond Register 			
#define UART_ONEMS_MASK			0xffff

// UART_TS - Test Register 1 					
#define UART_TS_FRCPERR			BIT13		// 1 = Force inverted parity (if enabled)
#define UART_TS_LOOP			BIT12		// 1 = Internally connect Tx to Rx 
#define UART_TS_DBGEN			BIT11		// 1 = UART in debug mode even if debug_d is LOW 
#define UART_TS_LOOPIR			BIT10		// 1 = Connect IR transmitter to IR Receiver, 0 = NO IR loop 
#define UART_TS_RXDBG			BIT9		// 1 = RX FIFO reads pointer increments as normal, 0 = does not increment
#define UART_TS_TXEMPTY			BIT6		// 1 = The TxFIFO is empty
#define UART_TS_RXEMPTY			BIT5		// 1 = The RxFIFO is empty
#define UART_TS_TXFULL			BIT4		// 1 = The TxFIFO is full
#define UART_TS_RXFULL			BIT3		// 1 = The RxFIFO is full
#define UART_TS_SOFTRST			BIT0		// software reset status

