/* Monitor configuration file.
    General notice:
    This code is part of a boot-monitor package developed as a generic base
    platform for embedded system designs.  As such, it is likely to be
    distributed to various projects beyond the control of the original
    author.  Please notify the author of any enhancements made or bugs found
    so that all may benefit from the changes.  In addition, notification back
    to the author will allow the new user to pick up changes that may have
    been made by other users after this version of the code was distributed.

    Author: Ed Sutter
    email:  esutter@lucent.com
    phone:  908-582-2351
*/

#ifndef CONFIG_H
#define CONFIG_H

#define FORCE_BSS_INIT
#define CPU_BE

/* Specify CPU/PLATFORM type and name so that common code can be used
 * for a similar cpu, on different platforms.
 * The 'TYPE' definition is used for ifdefs in the code and the 'NAME'
 * is used for printfs in the code.
 */
#define CPU_TYPE        MPC5121e
#define CPU_NAME        "PowerPC MPC5121e"
#define PLATFORM_TYPE   CSB781
#define PLATFORM_NAME   "Cogent CSB781"

//#define RAM_VECTOR_TABLE    0x0

// override the app ram base to set it to 3Mbyte.  This reserves space
// for umon, TFS in ram and the shared PCI window
#define APPRAMBASE_OVERRIDE 0x00300000
//#define BOOTROMBASE_OVERRIDE 0xfc000000
#define BOOTROMBASE_OVERRIDE 0xfff00000

/* define DONT_USE_SRAM such that uMon won't use SRAM for the BD
 * tx and rx buffers.  This will also disable the cache
 */
#define DONT_USE_SRAM

/* XBUFCNT & RBUFCNT:
 *  Number of transmit and receive buffers allocated to ethernet.
 *  The total of XBUFCNT+RBUFCNT should not exceed MAXEBDS
 */
#define XBUFCNT 	8
#define RBUFCNT 	8
#define XBUFSIZE	2048
#define RBUFSIZE	2048

//#define TIMER_TICKS_PER_MSEC	100000

/* DEFAULT_ETHERADD & DEFAULT_IPADD:
 *  Refer to notes in ethernet.c function EthernetStartup() for details
 *  regarding the use of these definitions.
 */
#define	DEFAULT_ETHERADD "00:30:23:81:00:"
#define	DEFAULT_IPADD	 "192.168.254.214"

/* Defining DONT_CENTER_MONHEADER will eliminate the automatic centering
 * of the monitor's startup banner...
 */
#define DONT_CENTER_MONHEADER

/* LOOPS_PER_SECOND:
 * Approximately the size of a loop that will cause a 1-second delay.
 * This can be guestimated or modified with the sleep -c command at the
 * monitor command line.
 */
#define LOOPS_PER_SECOND    15000

/* Flash bank configuration:
 * This target is configured with one flash bank.
 */
#define FLASHBANKS              1
#define SINGLE_FLASH_DEVICE		1		
#define FLASH_COPY_TO_RAM		1
#define FLASH_BANK0_BASE_ADDR	0xfc000000
#define FLASH_PROTECT_RANGE		"0-4"
#define FLASH_BANK0_WIDTH       2
#define FLASH_LARGEST_SECTOR    0x20000
#define FLASH_TIMEOUT			1000000
#define BUFFERED_WRITE

/* TFS definitions:
 *  TFSSTART:       Base address in FLASH at which TFS starts.
 *  TFSEND:         End address of TFS in FLASH.
 *  TFSSPARE:       Location of sector that is used as the spare sector
 *                  by TFS for defragmentation.
 *  TFSSPARESIZE:   Size of the spare sector used by TFS for defragmentation.
 *  TFSSECTORCOUNT: Number of eraseable sectors that TFS covers, not including
 *                  the TFSSPARE sector.
 */
#define TFSSPARESIZE    		FLASH_LARGEST_SECTOR
#define TFS_DEVTOT      		1
#define TFSSTART        		(FLASH_BANK0_BASE_ADDR+0x100000)
#define TFSEND          		(FLASH_BANK0_BASE_ADDR+0x007dffff)	// 8MB Flash
//#define TFSEND          		(FLASH_BANK0_BASE_ADDR+0x00fdffff)	// 16MB Flash
//#define TFSEND          		(TFSSTART+0x00fdffff)	// 16MB Flash
//#define TFSEND          		(FLASH_BANK0_BASE_ADDR+0x03dfffff)	// 64MB Flash
#define TFSSPARE        		(TFSEND+1)
#define TFSSECTORCOUNT			((TFSSPARE-TFSSTART)/0x20000)
#define TFS_EBIN_ELFMSBIN		1
#define TFS_VERBOSE_STARTUP		1
#define TFS_ALTDEVTBL_BASE		&alt_tfsdevtbl_base


/* Specify the size of the memory block (in monitor space) that is to be
 * allocated to malloc in the monitor.  Note that this size can be dynamically
 * increased through the HEAPBASE and HEAPSTART shell variables.
 */
#define ALLOCSIZE		(64*1024)
#define MONSTACKSIZE	(16*1024)

/* Specify inclusion of subsystems within the monitor here.
 */
#define INCLUDE_MEMCMDS         1	//	1
#define INCLUDE_EDIT            1	//	1
#define INCLUDE_DISASSEMBLER    1	//	1
#define INCLUDE_UNZIP           1	//	1
#define INCLUDE_ETHERNET        1	//	1
#define INCLUDE_ICMP			1	//	1
#define INCLUDE_TFTP            1	//	1
#define INCLUDE_DHCPBOOT        1	//	1
#define INCLUDE_TFS             1	//	1
#define INCLUDE_TFSCLI          1	//	1
#define INCLUDE_TFSAPI          1	//	1
#define INCLUDE_TFSSYMTBL       1	//	1
#define INCLUDE_TFSSCRIPT       1	//	1
#define INCLUDE_XMODEM          1	//	1
#define INCLUDE_LINEEDIT        1	//	1
#define INCLUDE_EE              1	//	1
#define INCLUDE_FLASH           1	//	1
#define INCLUDE_MALLOC			1	//	1
#define INCLUDE_SHELLVARS		1	//	1
#define INCLUDE_STRACE          1	//	1
#define INCLUDE_CAST            1	//	1
#define INCLUDE_STRUCT          1	//	1
#define INCLUDE_REDIRECT        1	//	1
#define INCLUDE_QUICKMEMCPY     1	//	1
#define INCLUDE_PROFILER        1	//	0
#define INCLUDE_BBC             0	//	0
#define INCLUDE_MEMTRACE        1	//	1
#define INCLUDE_SPRCMD          1	//	1
#define INCLUDE_DCRCMD          1	//	1
#define INCLUDE_TRAPCMD         1	//	0
#define INCLUDE_STOREMAC		1	//	0
#define INCLUDE_VERBOSEHELP		1	//	1
#define INCLUDE_HWTMR			0	//	0
#define INCLUDE_PORTCMD			0	//	0
#define INCLUDE_SYSLOG			1	//	1
#define INCLUDE_USRLVL			1	//	1
#define INCLUDE_LCD				1	//	0
#define INCLUDE_FBI				1
#define INCLUDE_TSI				0

/* Inclusion of this next file will make sure that all of the above
 * inclusions are legal; and adjust where necessary.
 */
#include "inc_check.h"

#endif  /* CONFIG_H */
