/*
 * General notice:
 * This code is part of a boot-monitor package developed as a generic base
 * platform for embedded system designs.  As such, it is likely to be
 * distributed to various projects beyond the control of the original
 * author.  Please notify the author of any enhancements made or bugs found
 * so that all may benefit from the changes.  In addition, notification back
 * to the author will allow the new user to pick up changes that may have
 * been made by other users after this version of the code was distributed.
 *
 * Author:	Ed Sutter
 * email:	esutter@lucent.com
 * phone:	908-582-2351
 * 
 */
	.file "reset.s"

#include "config.h"
#include "arch_ppc.h"
#include "e300.h"
#include "masks860.h"
#include "warmstart.h"
#include "mpc5121e.h"

	.globl	coldstart
	.globl	endlessloop
	.globl	warmstart
	.globl  SPInit
	.extern	start
	.extern MonStack

TEXT_BASE  =   0xFFF00000

//#define CONFIG_DEFAULT_IMMR		0xff400000
#define CFG_IMMR				0x80000000
#define IMMRBAR					0x0000
#define MBAR					311

#define CFG_HID0_INIT	0x000000000
#define CFG_HID0_FINAL	HID0_ENABLE_MACHINE_CHECK
#define CFG_HID2	HID2_HBE

#define CFG_SRAM_BASE		0x30000000
#define CFG_SRAM_SIZE		0x00020000	/* 128 KB */

#define CFG_CS0_CFG		0x03039110	/* (From BDI) ALE active low, data size 4bytes */
//#define CFG_CS2_CFG		0x05059010	/* ALE active low, data size 1byte */

/*
 * Internal Definitions
 *
 * Boot Flags
 */
#define BOOTFLAG_COLD		0x01	/* Normal Power-On: Boot from FLASH */
#define BOOTFLAG_WARM		0x02	/* Software reboot */

/*
 * NOR FLASH on the Local Bus
 */
#define CFG_FLASH_CFI				/* use the Common Flash Interface */
#define CFG_FLASH_CFI_DRIVER			/* use the CFI driver */
#define CFG_FLASH_BASE		0xFC00FFFF	/* start of FLASH   */
#define CFG_FLASH_SIZE		0x04000000	/* max flash size in bytes */

#define CFG_FLASH_USE_BUFFER_WRITE
#define CFG_MAX_FLASH_BANKS	1		/* number of banks */
#define CFG_FLASH_BANKS_LIST	{CFG_FLASH_BASE}
#define CFG_MAX_FLASH_SECT	256		/* max sectors per device */

#undef CFG_FLASH_CHECKSUM

/* Use SRAM for initial stack */
#define CFG_INIT_RAM_ADDR	CFG_SRAM_BASE		/* Initial RAM address */
#define CFG_INIT_RAM_END	CFG_SRAM_SIZE		/* End of used area in RAM */

#define CFG_GBL_DATA_SIZE	0x100			/* num bytes initial data */
#define CFG_GBL_DATA_OFFSET	(CFG_INIT_RAM_END - CFG_GBL_DATA_SIZE)
#define CFG_INIT_SP_OFFSET	CFG_GBL_DATA_OFFSET

#define CFG_MONITOR_BASE	TEXT_BASE		/* Start of monitor */
#define CFG_MONITOR_LEN		(256 * 1024)		/* Reserve 256 kB for Mon */
#ifdef	CONFIG_FSL_DIU_FB
#define CFG_MALLOC_LEN		(6 * 1024 * 1024)	/* Reserved for malloc */
#else
#define CFG_MALLOC_LEN		(512 * 1024)
#endif

/*
 * Floating Point enable, Machine Check and Recoverable Interr.
 */
#undef	MSR_KERNEL
#ifdef DEBUG
#define MSR_KERNEL (MSR_FP|MSR_RI)
#else
#define MSR_KERNEL (MSR_FP|MSR_ME|MSR_RI)
#endif

/* Macros for manipulating CSx_START/STOP */
#define START_REG(start)	((start) >> 16)
#define STOP_REG(start, size)	(((start) + (size) - 1) >> 16)

/*
 * Vector Table
 */
	.text
	. = EXC_OFF_SYS_RESET

	.globl	_start
	/* Start from here after reset/power on */
_start:
	li	r21, BOOTFLAG_COLD  /* Normal Power-On: Boot from FLASH */
	b	coldstart


#include "moncomptr.S"
#include "etheraddr.S"
#include "alttfsdevtbl.S"

	.balign		0x0100

coldstart:
	/* Save msr contents */
	mfmsr	r5

	/* Set IMMR area to our preferred location */
	lis	r4, CONFIG_DEFAULT_IMMR@h
	lis	r3, CFG_IMMR@h
	ori	r3, r3, CFG_IMMR@l
	stw	r3, IMMRBAR(r4)
	mtspr	MBAR, r3		/* IMMRBAR is mirrored into the MBAR SPR (311) */

	/* Initialise the machine */
	//bl	cpu_early_init

	/*
	 * Set up Local Access Windows:
	 *
	 * 1) Boot/CS0 (boot FLASH)
	 * 2) On-chip SRAM (initial stack purposes)
	 */

	/* Boot CS/CS0 window range */
	lis     r3, CFG_IMMR@h
	ori     r3, r3, CFG_IMMR@l

	lis	r4, CFG_FLASH_BASE@h
	ori	r4, r4, CFG_FLASH_BASE@l
	stw	r4, LPCS0AW(r3)

	/*
	 * The SRAM window has a fixed size (256K), so only the start address
	 * is necessary
	 */
	lis	r4, START_REG(CFG_SRAM_BASE) & 0xff00
	stw	r4, SRAMBAR(r3)

	/*
	 * According to MPC5121e RM, configuring local access windows should
	 * be followed by a dummy read of the config register that was
	 * modified last and an isync
	 */
	lwz	r4, SRAMBAR(r3)
	isync

	/*
	 * Set configuration of the Boot/CS0, the SRAM window does not have a
	 * config register so no params can be set for it
	 */
	lis     r3, (CFG_IMMR + LPC_OFFSET)@h
	ori     r3, r3, (CFG_IMMR + LPC_OFFSET)@l

	lis     r4, CFG_CS0_CFG@h
	ori     r4, r4, CFG_CS0_CFG@l
	stw     r4, CS0_CONFIG(r3)

	/* Master enable all CS's */
	lis	r4, CS_CTRL_ME@h
	ori	r4, r4, CS_CTRL_ME@l
	stw	r4, CS_CTRL(r3)

	lis	r4, (CFG_MONITOR_BASE)@h
	ori	r4, r4, (CFG_MONITOR_BASE)@l
	addi	r5, r4, in_flash - _start + EXC_OFF_SYS_RESET
 	mtlr	r5
	blr

in_flash:
	lis	r1, (CFG_INIT_RAM_ADDR + CFG_GBL_DATA_OFFSET)@h
	ori	r1, r1, (CFG_INIT_RAM_ADDR + CFG_GBL_DATA_OFFSET)@l

	li	r0, 0		/* Make room for stack frame header and	*/
 	stwu	r0, -4(r1)	/* clear final stack frame so that	*/
	stwu	r0, -4(r1)	/* stack backtraces terminate cleanly	*/

	/* let the C-code set up the rest			*/
	/*							*/
	/* Be careful to keep code relocatable & stack humble	*/
	/*------------------------------------------------------*/

	/* r3: IMMR */
	lis	r3, CFG_IMMR@h

	/* r3: BOOTFLAG */
	mr	r3, r21
	/* run 1st part of board init code (in Flash) */
	bl	csb781_init2		// call the remaining init code in c
	nop

warmstart:
    /* Disable I&D Cache before accessing any registers
     */
    mfspr   r5,DC_CST
    lis     r5,0x0400
    mtspr   DC_CST,r5
    isync
    mfspr   r5,IC_CST
    lis     r5,0x0400
    mtspr   IC_CST,r5
    isync

    /* Initialize MSR & SRR1
     */
    lis     r5,(MSR_ME|MSR_RI)@h
    ori     r5,r5,(MSR_ME|MSR_RI)@l
    mtmsr   r5
    isync
    mtspr   srr1,r5
    isync

    /* Initialize ICTRL, ICR & DEC:
     */
    lis     r5,(ISCT_SER7)@h
    ori		r5,r5,(ISCT_SER7)@l
    mtspr   ICTRL,r5
    lis     r5,(0)@h
    ori		r5,r5,(0)@l
    mtspr   ICR,r5
    lis     r5,(0x7FFFFFFF)@h
    ori     r5,r5,(0x7FFFFFFF)@l
    mtspr   dec,r5

	li		r0,r0
	mtmsr	r0				# Disable FPU/MMU/exceptions
	isync

SPInit:
    /* initialize the stack pointer, and be assured that it is mod16 */
    lis     sp, (MonStack+MONSTACKSIZE-4)@h
    ori     sp, sp, (MonStack+MONSTACKSIZE-4)@l
    addis   r5, r0, 0xffff
    ori     r5, r5, 0xfff8
    and     r1, r1, r5

GoToC:
	ba		start
	nop


/*
 * This code initialises the machine, it expects original MSR contents to be in r5.
 */
//cpu_early_init:
//	/* Initialize machine status; enable machine check interrupt */
//	/*-----------------------------------------------------------*/
//
//	li	r3, MSR_KERNEL			/* Set ME and RI flags */
//	rlwimi	r3, r5, 0, 25, 25		/* preserve IP bit */
//#ifdef DEBUG
//	rlwimi	r3, r5, 0, 21, 22		/* debugger might set SE, BE bits */
//#endif
//	mtmsr	r3
//	SYNC
//	mtspr	SRR1, r3			/* Mirror current MSR state in SRR1 */
//
//	lis	r3, CFG_IMMR@h
//
//#if defined(CONFIG_WATCHDOG)
//	/* Initialise the watchdog and reset it */
//	/*--------------------------------------*/
//	lis r4, CFG_WATCHDOG_VALUE
//	ori r4, r4, (SWCRR_SWEN | SWCRR_SWRI | SWCRR_SWPR)
//	stw r4, SWCRR(r3)
//
//	/* reset */
//	li	r4, 0x556C
//	sth	r4, SWSRR@l(r3)
//	li	r4, 0x0
//	ori	r4, r4, 0xAA39
//	sth	r4, SWSRR@l(r3)
//#else
//	/* Disable the watchdog */
//	/*----------------------*/
//	lwz r4, SWCRR(r3)
//	/*
//	 * Check to see if it's enabled for disabling: once disabled by s/w
//	 * it's not possible to re-enable it
//	 */
//	andi. r4, r4, 0x4
//	beq 1f
//	xor r4, r4, r4
//	stw r4, SWCRR(r3)
//1:
//#endif /* CONFIG_WATCHDOG */
//
//	/* Initialize the Hardware Implementation-dependent Registers */
//	/* HID0 also contains cache control			*/
//	/*------------------------------------------------------*/
//	lis	r3, CFG_HID0_INIT@h
//	ori	r3, r3, CFG_HID0_INIT@l
//	SYNC
//	mtspr	HID0, r3
//
//	lis	r3, CFG_HID0_FINAL@h
//	ori	r3, r3, CFG_HID0_FINAL@l
//	SYNC
//	mtspr	HID0, r3
//
//	lis	r3, CFG_HID2@h
//	ori	r3, r3, CFG_HID2@l
//	SYNC
//	mtspr	HID2, r3
//	sync
//	blr
//
